/**
 * Core Services API
 * API covering the [Networking](/iaas/Content/Network/Concepts/overview.htm),
[Compute](/iaas/Content/Compute/Concepts/computeoverview.htm), and
[Block Volume](/iaas/Content/Block/Concepts/overview.htm) services. Use this API
to manage resources such as virtual cloud networks (VCNs), compute instances, and
block storage volumes.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Represents an attachment between a flow log configuration and a resource such as a subnet. By
 * creating a `FlowLogConfigAttachment`, you turn on flow logs for the attached resource. See
 * {@link #createFlowLogConfigAttachment(CreateFlowLogConfigAttachmentRequest) createFlowLogConfigAttachment}.
 * <p>
 **Warning:** Oracle recommends that you avoid using any confidential information when you
 * supply string values using the API.
 *
 */
export interface FlowLogConfigAttachment {
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment containing the
     * flow log configuration attachment.
     *
     */
    "compartmentId": string;
    /**
     * A user-friendly name. Does not have to be unique, and it's changeable. Avoid
     * entering confidential information.
     *
     */
    "displayName": string;
    /**
     * The flow log configuration attachment's [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
     */
    "id": string;
    /**
     * The flow log configuration attachment's current state.
     */
    "lifecycleState": FlowLogConfigAttachment.LifecycleState;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the resource that the flow log
     * configuration is attached to.
     *
     */
    "targetEntityId": string;
    /**
     * The type of resource that the flow log configuration is attached to.
     *
     */
    "targetEntityType": FlowLogConfigAttachment.TargetEntityType;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the flow log configuration that
     * is attached to the resource.
     *
     */
    "flowLogConfigId": string;
    /**
      * The date and time the flow log configuration attachment was created, in the format defined by RFC3339.
  * <p>
  Example: `2016-08-25T21:10:29.600Z`
  *
      */
    "timeCreated": Date;
}
export declare namespace FlowLogConfigAttachment {
    enum LifecycleState {
        PROVISIONING = "PROVISIONING",
        AVAILABLE = "AVAILABLE",
        TERMINATING = "TERMINATING",
        TERMINATED = "TERMINATED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UNKNOWN_VALUE = "UNKNOWN_VALUE"
    }
    enum TargetEntityType {
        SUBNET = "SUBNET",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UNKNOWN_VALUE = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: FlowLogConfigAttachment): object;
}
