/**
 * Core Services API
 * API covering the [Networking](/iaas/Content/Network/Concepts/overview.htm),
[Compute](/iaas/Content/Compute/Concepts/computeoverview.htm), and
[Block Volume](/iaas/Content/Block/Concepts/overview.htm) services. Use this API
to manage resources such as virtual cloud networks (VCNs), compute instances, and
block storage volumes.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
* Details regarding a local peering connection, which is an entity that allows two VCNs to communicate
* without traversing the Internet.
* <p>
To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
* talk to an administrator. If you're an administrator who needs to write policies to give users access, see
* [Getting Started with Policies](https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).
* <p>
**Warning:** Oracle recommends that you avoid using any confidential information when you
* supply string values using the API.
*
*/
export interface LocalPeeringConnection {
    /**
     * The OCID of the compartment containing the local peering connection.
     */
    "compartmentId": string;
    /**
     * A user-friendly name. Does not have to be unique, and it's changeable.
     */
    "displayName": string;
    /**
     * The local peering connection's Oracle ID (OCID).
     */
    "id": string;
    /**
     * Indicates whether the peer local peering connection is contained within another tenancy.
     *
     */
    "isCrossTenancyPeering"?: boolean;
    /**
     * The local peering connection's current lifecycle state.
     */
    "lifecycleState": LocalPeeringConnection.LifecycleState;
    /**
     * Indicates the range of IPs available on the peer. `null` if not peered.
     */
    "peerAdvertisedCidr"?: string;
    /**
     * Indicates whether the local peering connection is peered with another local peering connection.
     */
    "peeringStatus": LocalPeeringConnection.PeeringStatus;
    /**
     * Additional information regarding the peering status if applicable.
     */
    "peeringStatusDetails"?: string;
    /**
      * The date and time the local peering connection was created, in the format defined by RFC3339.
  * <p>
  Example: `2016-08-25T21:10:29.600Z`
  *
      */
    "timeCreated": Date;
    /**
     * The OCID of the VCN the local peering connection belongs to.
     */
    "vcnId": string;
}
export declare namespace LocalPeeringConnection {
    enum LifecycleState {
        PROVISIONING = "PROVISIONING",
        AVAILABLE = "AVAILABLE",
        TERMINATING = "TERMINATING",
        TERMINATED = "TERMINATED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UNKNOWN_VALUE = "UNKNOWN_VALUE"
    }
    enum PeeringStatus {
        INVALID = "INVALID",
        NEW = "NEW",
        PEERED = "PEERED",
        PENDING = "PENDING",
        REVOKED = "REVOKED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UNKNOWN_VALUE = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: LocalPeeringConnection): object;
}
